# Copyright (c) 2008 Infrae. All rights reserved.
# See also LICENSE.txt
# $Id: membership.py 28228 2008-04-04 16:24:55Z sylvain $

from zope.interface import implements


from AccessControl.SecurityInfo import ClassSecurityInfo
from Products.PageTemplates.PageTemplateFile import PageTemplateFile
from Products.PluggableAuthService.plugins.BasePlugin import BasePlugin
from Products.PluggableAuthService.interfaces.plugins import IUserEnumerationPlugin

from Products.Silva.interfaces import IMember

manage_addMembershipPluginForm = PageTemplateFile("../www/membershipAddForm", 
                globals(), __name__="manage_addMembershipPluginForm")

def manage_addMembershipPlugin(self, id, title='', REQUEST=None):
    """Add a membership plugin to a Pluggable Authentication Service.
    """
    p=MembershipPlugin(id, title)
    self._setObject(p.getId(), p)

    if REQUEST is not None:
        REQUEST["RESPONSE"].redirect("%s/manage_workspace"
                "?manage_tabs_message=Membership+plugin+added." %
                self.absolute_url())


class MembershipPlugin(BasePlugin):
    """Plugin retrieving users defined in Silva
    """
    
    meta_type = 'Silva Membership PAS Plugin'
    security = ClassSecurityInfo()

    implements(IUserEnumerationPlugin)

    def __init__(self, id, title=None):
        self._setId(id)
        self.title=title


    def enumerateUsers(self, id=None, login=None,
                       exact_match=False,
                       sort_by=None,
                       max_results=None,
                       **kw
                       ):
        users = []
        root = self.get_root()
        members = root.Members
        if login is None:
            login = id
        for obj_id, obj in members.objectItems():
            if IMember.providedBy(obj):
                if ((exact_match and obj_id == login) or
                    (not exact_match and obj_id.startswith(login))):
                    users.append({'id': obj_id,
                                  'login': obj_id,
                                  'pluginid': self.getId()})
        return tuple(users)




# Copyright (c) 2008 Infrae. All rights reserved.
# See also LICENSE.txt
# $Id: __init__.py 28225 2008-04-04 16:06:09Z sylvain $

from AccessControl.Permissions import manage_users as ManageUsers
from Products.PluggableAuthService.PluggableAuthService import registerMultiPlugin
from plugins import membership
registerMultiPlugin(membership.MembershipPlugin.meta_type)


def initialize(context):
    context.registerClass(membership.MembershipPlugin,
                          permission=ManageUsers,
                          constructors=
                          (membership.manage_addMembershipPluginForm,
                           membership.manage_addMembershipPlugin),
                          visibility=None,
                          icon="www/members.png")




# Copyright (c) 2008 Infrae. All rights reserved.
# See also LICENSE.txt
# $Id: setup.py 28853 2008-05-27 09:24:34Z sylvain $

from setuptools import setup, find_packages
import os

version = '1.0'

setup(name='silva.pas.membership',
      version=version,
      description="Retrieve Silva membership information in PAS",
      long_description=open("README.txt").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      classifiers=[
        "Framework :: Zope2",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: BSD License",
        ],
      keywords='silva pas membership',
      author='Sylvain Viollon',
      author_email='info@infrae.com',
      url='https://svn.silva.com/silva.pas.membership/trunk',
      license='BSD',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['silva', 'silva.pas'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
              'silva.pas.base',
              'setuptools',
              ],
      )
